<TS language="fi" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Tietoa Gridcoinista</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Luo uusi osoite</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Uusi</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopioi valittu osoite leikepöydälle</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopioi</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Näytä &amp;QR-koodi</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Allekirjoita viesti osoittaaksesi Gridcoin-osoitteesi omistajuus</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Allekirjoita &amp;Viesti</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Vahvista viesti varmistaaksesi että kyseinen Gridcoin-osoitteesi on allekirjoittanut sen</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Varmista viesti</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Poista valittu osoite listalta</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Osoitekirja</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Nämä ovat Gridcoin-osoitteesi rahansiirtojen vastaanottoa varten. Jos haluat, voit antaa jokaiselle lähettäjälle oman osoitteen jotta voit pitää kirjaa sinulle rahaa siirtäneistä henkilöistä.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopioi &amp;nimi</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Vie osoitekirjasta tietoja</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Virhe vietäessä</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Ei voida kirjoittaa tiedostoon %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Osoite</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ei nimeä)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Tunnuslauseen tekstinsyöttökenttä</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Kirjoita tunnuslause</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Uusi tunnuslause</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Toista uusi tunnuslause</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Sallii estettäväksi yksinkertaiset rahansiirrot kun käyttöjärjestelmän käyttäjätunnuksen turvallisuutta on rikottu. Tämä ei takaa oikeasti turvallisuutta.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Vain osakkuutta varten</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Salaa lompakko</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Tätä toimintoa varten sinun täytyy antaa lompakon tunnuslause sen avaamiseksi.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Avaa lompakko lukituksestaan</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Vaihda tunnuslause</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Anna vanha ja uusi tunnuslause.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Vahvista lompakon salaus</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Varoitus: Jos salaat lompakkosi ja hukkaat salasanasi, &lt;b&gt;MENETÄT KAIKKI KOLIKKOSI&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Haluatko varmasti salata lompakkosi?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Lompakko salattu</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin-ohjelma sulkee itsensä päättääkseen salauksen luonnin. Muista, että lompakon salaaminen ei täysin turvaa kolikoitasi haittaohjelmien aiheuttamien varkauksien uhalta.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>TÄRKEÄÄ: Kaikki vanhat lompakon varmuuskopiot tulisi korvata uusilla suojatuilla varmuuskopioilla. Turvallisuussyistä edelliset varmuuskopiot muuttuvat käyttökelvottomiksi, kun aloitat uuden salatun lompakon käytön.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Lompakon salaus epäonnistui</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Lompakon salaaminen epäonnistui sisäisen virheen vuoksi. Lompakkoasi ei salattu.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Annetut tunnuslauseet eivät täsmää.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Lompakon avaaminen epäonnistui.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Annettu tunnuslause oli väärä.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Lompakon tunnuslause vaihdettiin onnistuneesti.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Varoitus: Caps Lock-näppäin on käytössä!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>Vakava virhe kohdattu. Gridcoin-ohjelma ei voi enää jatkaa turvallisesti ja sulkee itsensä.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Lompakko</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Yleisnäkymä</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Lompakon tilanteen yleiskatsaus</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Lähetä</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Lähetä kolikkoja Gridcoin osoitteeseen</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Vastaanota</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Näytä osoitelista vastaanottaaksesi maksuja</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Selaa rahansiirtohistoriaa</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Muokkaa tallennettujen osoitteiden ja nimien listaa</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>L&amp;opeta</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Sulje ohjelma</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Tietoa Gridcoinista</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Näytä tietoja Gridcoinista</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Asetukset...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Mukauta Gridcoinin konfigurointiasetuksia</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Näytä / Piilota</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Salaa lompakko...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Vaihda Tunnuslause...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Vaihda lompakon salaukseen käytettävä tunnuslause</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Aukaise lompakko</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Avaa Lompakko</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Lukitse Lompakko</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Lukitse lompakko</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;Allekirjoita viesti...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Varmista &amp;viesti...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>Vie...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Vie data tämänhetkisestä välilehdestä tiedostoon</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Testausikkuna</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Avaa debuggaus- ja diagnostiikkakonsoli</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Asetukset</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Apua</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Gridcoin-asiakas</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Rahansiirtohistoria on ajan tasalla</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Saavutetaan verkkoa...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Viimeinen vastaanotettu lohko generoitu %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>Tämä rahansiirto ylittää siirtorajan. Voit silti lähettää sen %1 rahansiirtopalkkiota vastaan, joka siirretään rahansiirtoasi käsitteleville solmuille jotta se auttaisi ja tukisi verkkoa. Haluatko maksaa rahansiirtopalkkion?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Hyväksy rahansiirtopalkkio</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Lähetetyt rahansiirrot</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Saapuva rahansiirto</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI-merkkijonojen käsittely</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>URI-merkkijonoa ei voida jäsentää! Tämä voi johtua väärästä Gridcoin-osoitteesta tai väärässä muodossa olevista URI-parametreistä.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Lompakko on &lt;b&gt;salattu&lt;/b&gt; ja tällä hetkellä &lt;b&gt;lukittuna&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Varmuuskopioi lompakkosi</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Lompakkodata (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Varmuuskopion luonti epäonnistui</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Virhe tallentaessa lompakkotiedostoa uuteen sijaintiinsa.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Verkkohälytys</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Määrä:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Tavuja:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Määrä:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Palkkio:</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Rahan hallinta</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Heikko ulosanti:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Palkkion jälkeen:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Vaihtoraha:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Määrä</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Aika</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Vahvistuksia</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Vahvistettu</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Nimike</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Osoite</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopioi osoite</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopioi nimi</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopioi määrä</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopioi siirtotunnus</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopioi määrä</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopioi kulu</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopioi kulun jälkeen</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopioi tavuja</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopioi heikko ulosanti</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopioi vaihdos</translation>
    </message>
    <message>
        <source>DUST</source>
        <translation>pölyä</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>kyllä</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ei</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Tämä nimike muuttuu punaiseksi, jos rahansiirron koko on suurempi kuin 10000 tavua.

Tämä tarkoittaa, että ainakin %1 rahansiirtopalkkio per kilotavu tarvitaan.

Voi vaihdella välillä +/- 1 Tavu per syöte.</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Tämä nimike muuttuu punaiseksi, jos jokin asiakas saa pienemmän määrän kuin %1.

Tämä tarkoittaa, että ainakin %2 rahansiirtopalkkio tarvitaan.

Määrät alle 0.546 kertaa pienimmän rahansiirtokulun verran näytetään pölynä.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Tämä nimike muuttuu punaiseksi, jos vaihdos on pienempi kuin %1.

Tämä tarkoittaa, että ainakin %2 rahansiirtopalkkio tarvitaan.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ei nimeä)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>vaihdos %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(vaihdos)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Muokkaa osoitetta</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Nimi</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>Tämän syötteen nimike osoitekirjassa</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>Tämän syötteen nimike osoitekirjassa. Nimikettä voidaan muuttaa vain lähetysosoitteille.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Osoite</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Uusi vastaanottava osoite</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Uusi lähettävä osoite</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Muokkaa vastaanottajan osoitetta</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Muokkaa lähtevää osoitetta</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>Syöttämäsi osoite "%1" ei ole hyväksytty Gridcoin-osoite.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Osoite "%1" on jo osoitekirjassa.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Lompakkoa ei voitu avata.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Uuden avaimen luonti epäonnistui.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>versio</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Kulutus:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>komentokehotteen asetukset</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Yleiset</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Verkko</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Portin uudelleenohjaus &amp;UPnP:llä</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Käynnistä Gridcoin-asiakasohjelma automaattisesti kun olet kirjautunut järjestelmään.</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Käynnistä Gridcoin-asiakasohjelma kirjautuessas</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>Avaa Gridcoin-asiakkaalle automaattisesti portti reitittimestä. Tämä toimii vain, kun reitittimesi tukee UPnP:tä ja se on aktivoituna.</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>Välityspalvelimen IP-osoite (esim. 127.0.0.1)</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Portti</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxyn Portti (esim. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Ikkunaa suljettaessa vain pienentää Bitcoin-ohjelman ikkunan lopettamatta itse ohjelmaa. Kun tämä asetus on valittuna, ohjelman voi sulkea vain valitsemalla Lopeta ohjelman valikosta.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>Käyttöliittymän kieli voidaan valita tästä. Tämä asetus tulee voimaan vasta Gridcoin-asiakasohjelman uudelleenkäynnistyksen jälkeen.</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Näytä tai piilota Gridcoin-osoitteet rahansiirtolistassa.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Näytä osoitteet rahansiirrot listassa</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ikkuna</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Käytä</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Näytä ainoastaan ilmaisinalueella ikkunan pienentämisen jälkeen.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Pienennä ilmaisinalueelle työkalurivin sijasta</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>P&amp;ienennä suljettaessa</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Käyttöliittymä</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Käyttöliittymän kieli</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Yksikkö jona bitcoin-määrät näytetään</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Valitse mitä yksikköä käytetään ensisijaisesti bitcoin-määrien näyttämiseen.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Peruuta</translation>
    </message>
    <message>
        <source>default</source>
        <translation>oletus</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Tämä asetus tulee voimaan vasta Gridcoin-asiakasohjelman uudelleenkäynnistyksen jälkeen.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Antamasi proxy-osoite on virheellinen.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Lomake</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Käytettävissä:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Nykyinen käytettävissä oleva tase</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Epäkypsää:</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Näytettävät tiedot voivat olla vanhentuneet. Lompakkosi synkronoituu automaattisesti Gridcoin-verkon kanssa kun yhteys on muodostettu, mutta tätä prosessia ei ole viety vielä päätökseen.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Kaikki vahvistamattomat rahansiirrot yhteensä, joita ei vielä lasketa saldoosi.</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Yhteensä:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Tililläsi tällä hetkellä olevien Bitcoinien määrä</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>QR-koodidialogi</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Pyydä rahansiirtoa</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Nimike:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Viesti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Määrä:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Tallenna nimellä...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Virhe koodatessa linkkiä QR-koodiin.</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>Syötetty määrä on epäkelpoinen; tarkista.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>Tuloksena liian pitkä URI, yritä lyhentää nimikkeen tai viestin pituutta.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Tallenna QR-koodi</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Ei saatavilla</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Pääteohjelman versio</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>T&amp;ietoa</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Käynnistysaika</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Yhteyksien lukumäärä</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Lohkoketju</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Nykyinen Lohkojen määrä</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Viimeisimmän lohkon aika</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Avaa</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Tyhjennä</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsoli</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Verkkoliikenne</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Yhteensä</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Sisään:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Ulos:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Debug lokitiedosto</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Tyhjennä konsoli</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>Testiverkossa</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Arvioitu lohkojen kokonaismäärä</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Avaa Gridcoin-asiakasohjelman debug-lokitiedosto nykyisestä hakemistostaan. Tämä voi kestää muutaman sekunnin avattaessa suuria lokitiedostoja.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Komentokehotteen ominaisuudet</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Näytä</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Pääteohjelman nimi</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Ylös- ja alas-nuolet selaavat historiaa ja &lt;b&gt;Ctrl-L&lt;/b&gt; tyhjentää ruudun.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Kirjoita &lt;b&gt;help&lt;/b&gt; nähdäksesi yleiskatsauksen käytettävissä olevista komennoista.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Lähetä Bitcoineja</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Sisääntulot...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automaattisesti valitut</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Lompakon saldo ei riitä!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Määrä:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Tavuja:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Määrä:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Palkkio:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Heikko ulosanti:</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ei</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Palkkion jälkeen:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Vaihtoraha</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>erikseen määritetty vaihtorahaosoite</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Tyhjennä kaikki rahansiirtokentät</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Lähetä usealla vastaanottajalle samanaikaisesti</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Lisää &amp;Vastaanottaja</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Tyhjennnä Kaikki</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Vahvista lähetys</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Lähetä</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopioi määrä</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopioi määrä</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopioi rahansiirtokulu</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopioi rahansiirtokulun jälkeen</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopioi tavuja</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopioi heikko ulosanti</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopioi vaihtoraha</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; to %2 (%3)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt;:sta %2 (%3)</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Hyväksy Bitcoinien lähettäminen</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Oletko varma että haluat lähettää %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>ja</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Vastaanottajan osoite on virheellinen. Tarkista osoite.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Maksettavan summan tulee olla suurempi kuin 0 Bitcoinia.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Määrä ylittää käytettävissä olevan saldon.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Kokonaismäärä ylittää saldosi kun %1 maksukulu lisätään summaan.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Sama osoite toistuu useamman kerran. Samaan osoitteeseen voi lähettää vain kerran per maksu.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>Virhe: Rahansiirron luonti epäonnistui.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Virhe: Rahansiirto evätty. Tämä voi tapahtua kun jotkut kolikot lompakossasi ovat jo käytetty, kuten myös tilanteessa jos käytit wallet.dat-tiedoston kopiota ja rahat olivat käytetty kopiossa, mutta eivät ole merkitty käytetyiksi tässä.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ei nimeä)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>VAROITUS: Epäkelpo Gridcoin-osoite</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>VAROITUS: Tuntematon vaihtorahaosoite</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>M&amp;äärä:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Maksun saaja:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Viesti:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Nimi:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Kaavake</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Liitä osoite leikepöydältä</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Valitse osoite osoitekirjasta</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Poista tämä vastaanottaja</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Anna nimi tälle osoitteelle, jos haluat lisätä sen osoitekirjaan</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Allekirjoitukset - Allekirjoita / Varmista viesti</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Allekirjoita viesti</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Voit allekirjoittaa viestit omalla osoitteellasi todistaaksesi että omistat ne. Ole huolellinen, ettet allekirjoita mitään epämääräistä, sillä phishing-hyökkääjät voivat yrittää huijata sinua allekirjoittamaan henkilöllisyytesi heidän hyväksi. Allekirjoita vain se,  mihin olet sitoutunut.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Valitse osoite osoitekirjasta</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Liitä osoite leikepöydältä</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Kirjoita tähän viesti minkä haluat allekirjoittaa</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopioi tämänhetkinen allekirjoitus leikepöydälle</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Allekirjoita viesti vahvistaaksesi, että omistat tämän Gridcoin-osoitteen</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Allekirjoita &amp;viesti</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Tyhjennä kaikki allekirjoita-viesti-kentät</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;Tyhjennä Kaikki</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Varmista viesti</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Syötä allekirjoittava osoite, viesti ja allekirjoitus alla oleviin kenttiin varmistaaksesi allekirjoituksen aitouden. Varmista että kopioit kaikki kentät täsmälleen oikein, myös rivinvaihdot, välilyönnit, tabulaattorit, jne.</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Vahvista viesti varmistaaksesi että se on allekirjoitettu kyseisellä Gridcoin-osoitteella</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Tyhjennä kaikki varmista-viesti-kentät</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Klikkaa "Allekirjoita Viesti luodaksesi allekirjoituksen </translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Syötä Gridcoin-allekirjoitus</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Syötetty osoite on virheellinen.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Tarkista osoite ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Syötetyn osoitteen avainta ei löydy.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Lompakon avaaminen peruttiin.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Yksityistä avainta syötetylle osoitteelle ei ole saatavilla.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Viestin allekirjoitus epäonnistui.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Viesti allekirjoitettu.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Allekirjoitusta ei pystytty tulkitsemaan.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Tarkista allekirjoitus ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Allekirjoitus ei täsmää viestin tiivisteeseen.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Viestin varmistus epäonnistui.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Viesti varmistettu.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Avoinna %1 asti</translation>
    </message>
    <message>
        <source>conflicted</source>
        <translation>törmännyt</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/vahvistamaton</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 vahvistusta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, ei ole vielä onnistuneesti lähetetty</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Aika</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Lähde</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Lähettäjä</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>tuntematon</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Saaja</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>oma osoite</translation>
    </message>
    <message>
        <source>label</source>
        <translation>nimi</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>ei hyväksytty</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Maksukulu</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Netto määrä</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Viesti</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Viesti</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Määrä</translation>
    </message>
    <message>
        <source>true</source>
        <translation>tosi</translation>
    </message>
    <message>
        <source>false</source>
        <translation>epätosi</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Rahansiirron yksityiskohdat</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Tämä ruutu näyttää yksityiskohtaisen tiedon rahansiirrosta</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Aika</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Laatu</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Osoite</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Määrä</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Avoinna %1 asti</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Offline-tila</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Vahvistamaton</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Vahvistettu (%1 vahvistusta)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Törmännyt</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generoitu mutta ei hyväksytty</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Vastaanotettu osoitteella</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Vastaanotettu</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Saaja</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Maksu itsellesi</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(ei saatavilla)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Rahansiirron tila. Siirrä osoitin kentän päälle nähdäksesi vahvistusten lukumäärä.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Rahansiirron vastaanottamisen päivämäärä ja aika.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Rahansiirron laatu.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Rahansiirron kohteen Bitcoin-osoite</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Saldoon lisätty tai siitä vähennetty määrä.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Tällä viikolla</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Tässä kuussa</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Viime kuussa</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Tänä vuonna</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Alue...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Vastaanotettu osoitteella</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Saaja</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Itsellesi</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Louhittu</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimimäärä</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopioi osoite</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopioi nimi</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopioi määrä</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopioi rahansiirron ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Muokkaa nimeä</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Näytä rahansiirron yksityiskohdat</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Vie tiedot rahansiirrosta</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Vahvistettu</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Aika</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Laatu</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Osoite</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Määrä</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Virhe vietäessä</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Ei voida kirjoittaa tiedostoon %1.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Alue:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>kenelle</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Lähetetään...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Virhe ilmennyt asetettaessa RPC-porttia %u IPv6:n kuuntelemiseksi, palataan takaisin IPv4:ään %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Virhe valmisteltaessa RPC-portin %u avaamista kuunneltavaksi: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Käyttö:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Lista komennoista</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Hanki apua käskyyn</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Varoitus: -paytxfee on asetettu erittäin korkeaksi! Tämä on maksukulu jonka tulet maksamaan kun lähetät siirron.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Varoitus: wallet.dat-tiedosto on korruptoitunut, data pelastettu! Alkuperäinen wallet.dat on tallennettu nimellä wallet.{aikaleima}.bak kohteeseen %s; Jos saldosi tai rahansiirrot ovat väärät, sinun tulee palauttaa lompakko varmuuskopiosta.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Varoitus: Virhe luettaessa wallet.dat-tiedostoa! Kaikki avaimet luettiin oikein, mutta rahansiirtodata tai osoitekirjan kentät voivat olla puuttuvat tai väärät.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Virhe: Rahansiirron luonti epäonnistui</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Virhe: Rahansiirto on evätty. Tämä voi tapahtua jos joitakin kolikoistasi lompakossasi on jo käytetty, tai jos olet käyttänyt wallet.dat-tiedoston kopiota ja rahat olivat käytetyt kopiossa, mutta ei merkitty käytetyksi tässä.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Ei onnistuttu kuuntelemaan missään portissa. Käytä -listen=0 jos haluat tätä.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Käytä %s optiota</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Sinun täytyy asettaa rpcpassword=&lt;password&gt; asetustiedostoon:
%s
Jos tiedostoa ei ole, niin luo se ainoastaan omistajan kirjoitusoikeuksin.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>Gridcoinin versio</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>-paytxfee=&lt;amount&gt;: '%s' on virheellinen</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Epäkelpo määrä parametrille -mininput=&lt;amount&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Lompakko %s on datahakemiston %s ulkopuolella.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Tarkistetaan tietokannan eheyttä...</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Virhe alustettaessa tietokantaympäristöä %s! Palauttaaksesi sen, TEE VARMUUSKOPIO HAKEMISTOSTA ja poista tämän jälkeen kaikki hakemiston tiedostot paitsi wallet.dat-tiedosto.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat on korruptoitunut, pelastusyritys epäonnistui</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Virheellinen proxy-osoite '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Epäkelpo -tor-osoite: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>-bind osoitteen '%s' selvittäminen epäonnistui</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>-externalip osoitteen '%s' selvittäminen epäonnistui</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Epäkelpo määrä -reservebalance=&lt;amount&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Virhe ladattaessa blkindex.dat-tiedostoa</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Virhe ladattaessa wallet.dat-tiedostoa: Lompakko vioittunut</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Virhe ladattaessa wallet.dat-tiedostoa: Lompakko tarvitsee uudemman version Gridcoin-asiakasohjelmasta</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>Lompakko on kirjoitettava uudelleen: käynnistä Gridcoin-asiakasohjelma uudelleen päättääksesi toiminnon</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Virhe ladattaessa wallet.dat-tiedostoa</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Tuodaan esilatausohjelma lohkoketjun datatiedostolle.</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Ladataan osoitteita...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Virhe: Ei voitu käynnistää noodia</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>Ei voitu liittää %s tällä tietokoneella. Gridcoin-asiakasohjelma on jo ehkä päällä.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Kytkeytyminen %s tällä tietokonella ei onnistu (kytkeytyminen palautti virheen %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Virhe: Lompakko lukittu, rahansiirtoa ei voida luoda</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Virhe: Lompakko avattu vain osakkuutta varten, rahansiirtoja ei voida luoda.</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Virhe: Tämä rahansiirto tarvitsee rahansiirtopalkkion, kooltaan %s, kokonsa, monimutkaisuutensa tai aikaisemmin saatujen varojen käytön takia.</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Lähetetään...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Virheellinen määrä</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Varoitus: Tarkista, että tietokoneesi aika ja päivämäärä ovat oikeassa! Jos kellosi on väärässä, Gridcoin ei toimi oikein.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Varoitus: Kiintolevytila on vähissä!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Tuntematon verkko -onlynet parametrina: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Lompakon saldo ei riitä</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Ladataan lohkoindeksiä...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ladataan lompakkoa...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Oletusosoitetta ei voi kirjoittaa</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Skannataan uudelleen...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Lataus on valmis</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
</TS>